==> freeorion_0.4.5.orig.tar.gz: src-tarball/README.md <==
## Synopsis

Source code repository of the FreeOrion project.

FreeOrion is a free, open source, turn-based space empire and galactic conquest (4X) computer game being designed and built by the FreeOrion project. FreeOrion is inspired by the tradition of the Master of Orion games, but is not a clone or remake of that series or any other game. 

## Vision Statement

FreeOrion, an open-source game inspired by Master of Orion, is a turn-based game of epic space strategy that builds on the classic '4X' model by incorporating the nation-building elements of games such as Europa Universalis 2 and a versatile tactical combat engine. While its modular, open-source design allows for a significant degree of customization of the game engine and the story elements by the community, the FreeOrion team is dedicated to the construction of a living, breathing universe in a 'grand campaign' model.

## How to contribute

http://freeorion.org/index.php/How_to_Help

## License

Artistic or creative content is licensed under the Creative Commons Attribution-Share Alike 3.0 Unported license.
(http://creativecommons.org/licenses/by-sa/3.0/)

This includes artwork, music, sounds, text that determines how art, music or sound is played or displayed in game, game content such as technologies, buildings, specials and their associated in-game text, and the scripts that determine their in-game functionality.

Game content scripts are also licensed under the GNU General Public License, Version 2
(http://www.gnu.org/licenses/old-licenses/gpl-2.0.html).

Everything else is licensed under the GNU General Public License, Version 2.

## Homepage

http://freeorion.org

==> freeorion_0.4.6.orig.tar.gz: src-tarball/README.md <==
## Synopsis

Source code repository of the FreeOrion project.

FreeOrion is a free, open source, turn-based space empire and galactic conquest (4X) computer game being designed and built by the FreeOrion project. FreeOrion is inspired by the tradition of the Master of Orion games, but is not a clone or remake of that series or any other game. 

## Vision Statement

FreeOrion, an open-source game inspired by Master of Orion, is a turn-based game of epic space strategy that builds on the classic '4X' model by incorporating the nation-building elements of games such as Europa Universalis 2 and a versatile tactical combat engine. While its modular, open-source design allows for a significant degree of customization of the game engine and the story elements by the community, the FreeOrion team is dedicated to the construction of a living, breathing universe in a 'grand campaign' model.

## How to contribute

For more details please see our [Contribution Guidelines](CONTRIBUTING.md).


## License

Artistic or creative content is licensed under the Creative Commons Attribution-Share Alike 3.0 Unported license.
(http://creativecommons.org/licenses/by-sa/3.0/)

This includes artwork, music, sounds, text that determines how art, music or sound is played or displayed in game, game content such as technologies, buildings, specials and their associated in-game text, and the scripts that determine their in-game functionality.

Game content scripts are also licensed under the GNU General Public License, Version 2
(http://www.gnu.org/licenses/old-licenses/gpl-2.0.html).

Everything else is licensed under the GNU General Public License, Version 2.

## Homepage

http://freeorion.org
